@@ -5,7 +5,6 @@ from pydantic import BaseModel, validate_arguments
 
 from ..cache import cache
 from ..core import BaseClient
-from ..types import AccountType, Currency
 
 PATH = "/users/{user_uuid}/institutions"
 
@@ -13,9 +12,9 @@ PATH = "/users/{user_uuid}/institutions"
 class Institution(BaseModel):
     institution_id: str
     display_name: str
-    currency: Optional[Currency]
+    currency: Optional[str]
     account_ids: List[str]
-    account_types: List[AccountType]
+    account_types: List[str]
 
 
 class InstitutionsMeta(BaseModel):
